<div class="authredirect-page" x-data x-init="$nextTick(() => { window.scrollTo(0, 0) })">
    <h2>Please sign in or continue as guest</h2>
    <a href="/customer/account/login" class="action primary">Login</a>
    <a href="/checkout/#shipping" class="action secondary">Continue as Guest</a>
</div>
