<?php

namespace PortalPeople\AuthRedirect\Model\ResourceModel;

use Magento\Framework\Model\ResourceModel\Db\AbstractDb;

class LoginAttemptLog extends AbstractDb
{
    protected function _construct()
    {
        $this->_init('portalpeople_authredirect_login_attempt', 'attempt_id');
    }
}