<?php
namespace Custom\AuthRedirect\Plugin;

use Magento\Checkout\CustomerData\DefaultItem;

class RedirectPlugin
{
    public function afterGetSectionData(DefaultItem $subject, $result)
    {
        if (!isset($result['redirectUrl'])) {
            $result['redirectUrl'] = '/authredirect';
        }
        return $result;
    }
}
